netapp_ontap.models.nfs_service_protocol_v40_features API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nfs_service_protocol_v40_features`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NfsServiceProtocolV40FeaturesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NfsServiceProtocolV40Features object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `acl_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.0 ACLs is enabled.

  `acl_max_aces: Size GET POST PATCH`

    Specifies the maximum number of aces in a NFSv4.0 ACL.

    Example: 500

  `acl_preserve: bool GET POST PATCH`

    Specifies if the NFSv4 ACL is preserved or dropped when chmod is performed. In unified security style, this parameter also specifies if NTFS file permissions are preserved or dropped when chmod, chgrp, or chown are performed.

  `read_delegation_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.0 Read Delegation is enabled.

  `referrals_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.0 referrals is enabled.

  `write_delegation_enabled: bool GET POST PATCH`

    Specifies whether NFSv4.0 Write Delegation is enabled.